/*
* This file is part of Bielefeld Type Library (BTL).
*
* Copyright(c) Frederic Siepmann
* http://opensource.cit-ec.de/projects/btl
*
* This file may be licensed under the terms of of the
* GNU Lesser General Public License Version 3 (the ``LGPL''),
* or (at your option) any later version.
*
* Software distributed under the License is distributed
* on an ``AS IS'' basis, WITHOUT WARRANTY OF ANY KIND, either
* express or implied. See the LGPL for the specific language
* governing rights and limitations.
*
* You should have received a copy of the LGPL along with this
* program. If not, go to http://www.gnu.org/licenses/lgpl.html
* or write to the Free Software Foundation, Inc.,
* 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
*
* The development of this software was supported by the
* Excellence Cluster EXC 277 Cognitive Interaction Technology.
* The Excellence Cluster EXC 277 is a grant of the Deutsche
* Forschungsgemeinschaft (DFG) in the context of the German
* Excellence Initiative.
*
* Contributors: Leon Ziegler, Johannes Wienke, Matthias Schröder, Norman Köster,
* 				Lukas Twardon, Torben Töniges, Annika Rothert, Marian Pohling,
* 				Denis Schulze, Viktor Richter, Birte Carlmeyer, Maikel Linke
*/

/*
 * MapPoint.cpp
 *
 *  Created on: Oct 13, 2010
 *      Author: ltwardon
 */

#include "MapPoint.h"

using namespace std;
using namespace airobots;

namespace airobots {

const std::string MapPoint::kindValue[] = {
				"WORLD",
				"RELATIVE"};

MapPoint::MapPoint(){
	this->x=0;
	this->y=0;
	kind=MapPoint::WORLD;
	ref="";
}

MapPoint::MapPoint(double x, double y, LengthUnit lengthUnit){
		this->x = UnitConverter::convert(x,lengthUnit,internLengthUnit);
		this->y = UnitConverter::convert(y,lengthUnit,internLengthUnit);
		kind=MapPoint::WORLD;
		this->ref="";
}

MapPoint::MapPoint(double x, double y, MapPoint::Kind kind,LengthUnit lengthUnit ,string ref){
		this->x = UnitConverter::convert(x,lengthUnit,internLengthUnit);
		this->y = UnitConverter::convert(y,lengthUnit,internLengthUnit);
		this->kind=kind;
		this->ref=ref;
}

MapPoint::~MapPoint() {

}

double MapPoint::getX(LengthUnit lengthUnit) const {
	return UnitConverter::convert(x,internLengthUnit,lengthUnit);
}

void MapPoint::setX(double x,LengthUnit lengthUnit) {
	this->x = UnitConverter::convert(x,lengthUnit,internLengthUnit);
}

double MapPoint::getY(LengthUnit lengthUnit) const {
	return UnitConverter::convert(y,internLengthUnit,lengthUnit);
}

void MapPoint::setY(double y,LengthUnit lengthUnit) {
	this->y = UnitConverter::convert(y,lengthUnit,internLengthUnit);
}

MapPoint::Kind MapPoint::getKind() const {
	return kind;
}

void MapPoint::setKind(MapPoint::Kind kind) {
	this->kind = kind;
}

std::string MapPoint::getRef() const {
	return ref;
}

void MapPoint::setRef(std::string ref) {
	this->ref = ref;
}

}
