/*
* This file is part of Bielefeld Type Library (BTL).
*
* Copyright(c) Frederic Siepmann
* http://opensource.cit-ec.de/projects/btl
*
* This file may be licensed under the terms of of the
* GNU Lesser General Public License Version 3 (the ``LGPL''),
* or (at your option) any later version.
*
* Software distributed under the License is distributed
* on an ``AS IS'' basis, WITHOUT WARRANTY OF ANY KIND, either
* express or implied. See the LGPL for the specific language
* governing rights and limitations.
*
* You should have received a copy of the LGPL along with this
* program. If not, go to http://www.gnu.org/licenses/lgpl.html
* or write to the Free Software Foundation, Inc.,
* 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
*
* The development of this software was supported by the
* Excellence Cluster EXC 277 Cognitive Interaction Technology.
* The Excellence Cluster EXC 277 is a grant of the Deutsche
* Forschungsgemeinschaft (DFG) in the context of the German
* Excellence Initiative.
*
* Contributors: Leon Ziegler, Johannes Wienke, Matthias Schröder, Norman Köster,
* 				Lukas Twardon, Torben Töniges, Annika Rothert, Marian Pohling,
* 				Denis Schulze, Viktor Richter, Birte Carlmeyer, Maikel Linke
*/

/*
 * Point2D.h
 *
 *  Created on: Sep 6, 2010
 *      Author: maschroe
 */

#ifndef POINT2D_H_
#define POINT2D_H_

#include <xmltio/xmltio.hpp>
#include "../../Type.h"
#include "../../units/UnitConverter.h"

namespace airobots {

class Point2D : public Type {
public:
	enum Scope {
		GLOBAL, LOCAL
	};

	Point2D();
	Point2D(float x, float y, LengthUnit unit);
	Point2D(float x, float y, LengthUnit unit, Point2D::Scope scope);
	virtual ~Point2D();

	static std::string getBaseTag();
	static std::string getTemplate();

	Point2D::Scope getScope() const;
	float getX(LengthUnit unit = MILLIMETER) const;
	float getY(LengthUnit unit = MILLIMETER) const;
	void setScope(Point2D::Scope scope);
	void setX(float x, LengthUnit unit);
	void setY(float y, LengthUnit unit);

	bool operator==(const Point2D &other) const;

	void fillInto(xmltio::Location &loc) const;
	static void fromLocation(const xmltio::Location &loc, Point2D &type);
	void sanitizeLocation(xmltio::Location &loc) const;

private:
	float x;
	float y;
	Point2D::Scope scope;
};

}

#endif /* POINT2D_H_ */
