/*
* This file is part of Bielefeld Type Library (BTL).
*
* Copyright(c) Frederic Siepmann
* http://opensource.cit-ec.de/projects/btl
*
* This file may be licensed under the terms of of the
* GNU Lesser General Public License Version 3 (the ``LGPL''),
* or (at your option) any later version.
*
* Software distributed under the License is distributed
* on an ``AS IS'' basis, WITHOUT WARRANTY OF ANY KIND, either
* express or implied. See the LGPL for the specific language
* governing rights and limitations.
*
* You should have received a copy of the LGPL along with this
* program. If not, go to http://www.gnu.org/licenses/lgpl.html
* or write to the Free Software Foundation, Inc.,
* 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
*
* The development of this software was supported by the
* Excellence Cluster EXC 277 Cognitive Interaction Technology.
* The Excellence Cluster EXC 277 is a grant of the Deutsche
* Forschungsgemeinschaft (DFG) in the context of the German
* Excellence Initiative.
*
* Contributors: Leon Ziegler, Johannes Wienke, Matthias Schröder, Norman Köster,
* 				Lukas Twardon, Torben Töniges, Annika Rothert, Marian Pohling,
* 				Denis Schulze, Viktor Richter, Birte Carlmeyer, Maikel Linke
*/

/*
 * KatanaGripperData.cpp
 *
 *  Created on: May 25, 2010
 *      Author: ttoenige
 */

#include "KatanaGripperData.h"

using namespace airobots;
using namespace std;
using namespace xmltio;

std::string KatanaGripperData::getBaseTag()
{
	return "SENSORS";
}

std::string KatanaGripperData::getTemplate()
{
	return std::string("<") + getBaseTag() + "><GENERATOR/>"
			+ Timestamp::getTemplate() + "<FINGER position=\"right\">"
			+ "<FORCE name=\"inside_near\" value=\"\"/>"
			+ "<FORCE name=\"inside_far\" value=\"\"/>"
			+ "<INFRARED name=\"outside\" value=\"\"/>"
			+ "<INFRARED name=\"front\" value=\"\"/>"
			+ "<INFRARED name=\"inside_near\" value=\"\"/>"
			+ "<INFRARED name=\"inside_far\" value=\"\"/>" + "</FINGER>"

	+ "<FINGER position=\"left\">" + "<FORCE name=\"inside_near\" value=\"\"/>"
			+ "<FORCE name=\"inside_far\" value=\"\"/>"
			+ "<INFRARED name=\"outside\" value=\"\"/>"
			+ "<INFRARED name=\"front\" value=\"\"/>"
			+ "<INFRARED name=\"inside_near\" value=\"\"/>"
			+ "<INFRARED name=\"inside_far\" value=\"\"/>" + "</FINGER>"

	+ "<MIDDLE>" + "<INFRARED name=\"middle\" value=\"\"/>" + "</MIDDLE>"

	+ "</" + getBaseTag() + ">";
}

KatanaGripperData::KatanaGripperData() : Type("unknown")
{
	// TODO Auto-generated constructor stub

}

double KatanaGripperData::getForceLeftInsideFar() const
{
	return forceLeftInsideFar;
}

double KatanaGripperData::getForceLeftInsideNear() const
{
	return forceLeftInsideNear;
}

double KatanaGripperData::getForceRightInsideFar() const
{
	return forceRightInsideFar;
}

double KatanaGripperData::getForceRightInsideNear() const
{
	return forceRightInsideNear;
}

double KatanaGripperData::getInfraredLeftFront() const
{
	return infraredLeftFront;
}

double KatanaGripperData::getInfraredLeftInsideFar() const
{
	return infraredLeftInsideFar;
}

double KatanaGripperData::getInfraredLeftInsideNear() const
{
	return infraredLeftInsideNear;
}

double KatanaGripperData::getInfraredLeftOutside() const
{
	return infraredLeftOutside;
}

double KatanaGripperData::getInfraredMiddle() const
{
	return infraredMiddle;
}

double KatanaGripperData::getInfraredRightFront() const
{
	return infraredRightFront;
}

double KatanaGripperData::getInfraredRightInsideFar() const
{
	return infraredRightInsideFar;
}

double KatanaGripperData::getInfraredRightInsideNear() const
{
	return infraredRightInsideNear;
}

double KatanaGripperData::getInfraredRightOutside() const
{
	return infraredRightOutside;
}

void KatanaGripperData::setForceLeftInsideFar(double forceLeftInsideFar)
{
	this->forceLeftInsideFar = forceLeftInsideFar;
}

void KatanaGripperData::setForceLeftInsideNear(double forceLeftInsideNear)
{
	this->forceLeftInsideNear = forceLeftInsideNear;
}

void KatanaGripperData::setForceRightInsideFar(double forceRightInsideFar)
{
	this->forceRightInsideFar = forceRightInsideFar;
}

void KatanaGripperData::setForceRightInsideNear(double forceRightInsideNear)
{
	this->forceRightInsideNear = forceRightInsideNear;
}

void KatanaGripperData::setInfraredLeftFront(double infraredLeftFront)
{
	this->infraredLeftFront = infraredLeftFront;
}

void KatanaGripperData::setInfraredLeftInsideFar(double infraredLeftInsideFar)
{
	this->infraredLeftInsideFar = infraredLeftInsideFar;
}

void KatanaGripperData::setInfraredLeftInsideNear(double infraredLeftInsideNear)
{
	this->infraredLeftInsideNear = infraredLeftInsideNear;
}

void KatanaGripperData::setInfraredLeftOutside(double infraredLeftOutside)
{
	this->infraredLeftOutside = infraredLeftOutside;
}

void KatanaGripperData::setInfraredMiddle(double infraredMiddle)
{
	this->infraredMiddle = infraredMiddle;
}

void KatanaGripperData::setInfraredRightFront(double infraredRightFront)
{
	this->infraredRightFront = infraredRightFront;
}

void KatanaGripperData::setInfraredRightInsideFar(double infraredRightInsideFar)
{
	this->infraredRightInsideFar = infraredRightInsideFar;
}

void KatanaGripperData::setInfraredRightInsideNear(
		double infraredRightInsideNear)
{
	this->infraredRightInsideNear = infraredRightInsideNear;
}

void KatanaGripperData::setInfraredRightOutside(double infraredRightOutside)
{
	this->infraredRightOutside = infraredRightOutside;
}

void KatanaGripperData::sanitizeLocation(xmltio::Location &loc) const
{

}

void KatanaGripperData::fillInto(xmltio::Location &loc) const
{
	
	Type::fillInto(loc);

	loc[XPath("FINGER[@position=\"right\"]/FORCE[@name=\"inside_near\"]/@value")]
			= getForceRightInsideNear();
	loc[XPath("FINGER[@position=\"right\"]/FORCE[@name=\"inside_far\"]/@value")]
			= getForceRightInsideFar();
	loc[XPath("FINGER[@position=\"right\"]/INFRARED[@name=\"outside\"]/@value")]
			= getInfraredRightOutside();
	loc[XPath("FINGER[@position=\"right\"]/INFRARED[@name=\"front\"]/@value")]
			= getInfraredRightFront();
	loc[XPath(
			"FINGER[@position=\"right\"]/INFRARED[@name=\"inside_near\"]/@value")]
			= getInfraredRightInsideNear();
	loc[XPath(
			"FINGER[@position=\"right\"]/INFRARED[@name=\"inside_far\"]/@value")]
			= getInfraredRightInsideFar();

	loc[XPath("FINGER[@position=\"left\"]/FORCE[@name=\"inside_near\"]/@value")]
			= getForceLeftInsideNear();
	loc[XPath("FINGER[@position=\"left\"]/FORCE[@name=\"inside_far\"]/@value")]
			= getForceLeftInsideFar();
	loc[XPath("FINGER[@position=\"left\"]/INFRARED[@name=\"outside\"]/@value")]
			= getInfraredLeftOutside();
	loc[XPath("FINGER[@position=\"left\"]/INFRARED[@name=\"front\"]/@value")]
			= getInfraredLeftFront();
	loc[XPath(
			"FINGER[@position=\"left\"]/INFRARED[@name=\"inside_near\"]/@value")]
			= getInfraredLeftInsideNear();
	loc[XPath(
			"FINGER[@position=\"left\"]/INFRARED[@name=\"inside_far\"]/@value")]
			= getInfraredLeftInsideFar();

	loc[XPath("MIDDLE/INFRARED[@name=\"middle\"]/@value")]
			= getInfraredMiddle();

}

void KatanaGripperData::fromLocation(const xmltio::Location &loc_,
		KatanaGripperData &kgd)
{

	Type::fromLocation(loc_, kgd);

	kgd.setForceRightInsideNear(extract<double>(loc_[XPath(
			"FINGER[@position=\"right\"]/FORCE[@name=\"inside_near\"]/@value")]));
	kgd.setForceRightInsideFar(extract<double>(loc_[XPath(
			"FINGER[@position=\"right\"]/FORCE[@name=\"inside_far\"]/@value")]));
	kgd.setInfraredRightOutside(extract<double>(loc_[XPath(
			"FINGER[@position=\"right\"]/INFRARED[@name=\"outside\"]/@value")]));
	kgd.setInfraredRightFront(extract<double>(loc_[XPath(
			"FINGER[@position=\"right\"]/INFRARED[@name=\"front\"]/@value")]));
	kgd.setInfraredRightInsideNear(
			extract<double>(loc_[XPath(
					"FINGER[@position=\"right\"]/INFRARED[@name=\"inside_near\"]/@value")]));
	kgd.setInfraredRightInsideFar(
			extract<double>(loc_[XPath(
					"FINGER[@position=\"right\"]/INFRARED[@name=\"inside_far\"]/@value")]));

	kgd.setForceLeftInsideNear(extract<double>(loc_[XPath(
			"FINGER[@position=\"left\"]/FORCE[@name=\"inside_near\"]/@value")]));
	kgd.setForceLeftInsideFar(extract<double>(loc_[XPath(
			"FINGER[@position=\"left\"]/FORCE[@name=\"inside_far\"]/@value")]));
	kgd.setInfraredLeftOutside(extract<double>(loc_[XPath(
			"FINGER[@position=\"left\"]/INFRARED[@name=\"outside\"]/@value")]));
	kgd.setInfraredLeftFront(extract<double>(loc_[XPath(
			"FINGER[@position=\"left\"]/INFRARED[@name=\"front\"]/@value")]));
	kgd.setInfraredLeftInsideNear(
			extract<double>(loc_[XPath(
					"FINGER[@position=\"left\"]/INFRARED[@name=\"inside_near\"]/@value")]));
	kgd.setInfraredLeftInsideFar(
			extract<double>(loc_[XPath(
					"FINGER[@position=\"left\"]/INFRARED[@name=\"inside_far\"]/@value")]));

	kgd.setInfraredMiddle(
			extract<double>(loc_[XPath("MIDDLE/INFRARED[@name=\"middle\"]/@value")]));

}

