/*
* This file is part of Bielefeld Type Library (BTL).
*
* Copyright(c) Frederic Siepmann
* http://opensource.cit-ec.de/projects/btl
*
* This file may be licensed under the terms of of the
* GNU Lesser General Public License Version 3 (the ``LGPL''),
* or (at your option) any later version.
*
* Software distributed under the License is distributed
* on an ``AS IS'' basis, WITHOUT WARRANTY OF ANY KIND, either
* express or implied. See the LGPL for the specific language
* governing rights and limitations.
*
* You should have received a copy of the LGPL along with this
* program. If not, go to http://www.gnu.org/licenses/lgpl.html
* or write to the Free Software Foundation, Inc.,
* 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
*
* The development of this software was supported by the
* Excellence Cluster EXC 277 Cognitive Interaction Technology.
* The Excellence Cluster EXC 277 is a grant of the Deutsche
* Forschungsgemeinschaft (DFG) in the context of the German
* Excellence Initiative.
*
* Contributors: Leon Ziegler, Johannes Wienke, Matthias Schröder, Norman Köster,
* 				Lukas Twardon, Torben Töniges, Annika Rothert, Marian Pohling,
* 				Denis Schulze, Viktor Richter, Birte Carlmeyer, Maikel Linke
*/

/*
 * PositionData.h
 *
 *  Created on: Jul 31, 2009
 *      Author: jwienke
 */

#ifndef POSITIONDATA_H_
#define POSITIONDATA_H_

#include <string>
#include <xmltio/xmltio.hpp>
#include "../../Type.h"
#include "../../units/UnitConverter.h"

namespace airobots {

/**
 * Base class for types that contain positions.
 * Not abstract anymore.
 */
class PositionData : public Type{

public:

	static std::string getBaseTag();

	static std::string getTemplate();

	PositionData();
	PositionData(float x, float y, float theta,LengthUnit lengthUnit, AngleUnit angleUnit);
	virtual ~PositionData();

	float getX(LengthUnit lengthUnit) const;
	void setX(float x,LengthUnit lengthUnit);

	float getY(LengthUnit lengthUnit) const;
	void setY(float y,LengthUnit lengthUnit);

	float getTheta(AngleUnit angleUnit) const;
	void setTheta(float theta,AngleUnit angleUnit);

	void sanitizeLocation(xmltio::Location &loc) const;
	void fillInto(xmltio::Location &loc) const;
	static void fromLocation(const xmltio::Location &loc, PositionData &pos);

private:

	/**
	 * x coordinate relative to starting position [m],
	 * at orientation = 0, x axis is in forward direction
	 */
	float x; // m

	/**
	 * y coordinate relative to starting position [m],
	 * perpendicular-left to the positive x axis
	 */
	float y; // m

	/**
	 * orientation relative to starting orientation [rad],
	 * range is [-PI .. +PI], counter-clockwise
	 */
	float theta; // rad

};

}

#endif /* POSITIONDATA_H_ */
