/*
 * This file is part of Bielefeld Type Library (BTL).
 *
 * Copyright(c) Frederic Siepmann
 * http://opensource.cit-ec.de/projects/btl
 *
 * This file may be licensed under the terms of of the
 * GNU Lesser General Public License Version 3 (the ``LGPL''),
 * or (at your option) any later version.
 *
 * Software distributed under the License is distributed
 * on an ``AS IS'' basis, WITHOUT WARRANTY OF ANY KIND, either
 * express or implied. See the LGPL for the specific language
 * governing rights and limitations.
 *
 * You should have received a copy of the LGPL along with this
 * program. If not, go to http://www.gnu.org/licenses/lgpl.html
 * or write to the Free Software Foundation, Inc.,
 * 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
 *
 * The development of this software was supported by the
 * Excellence Cluster EXC 277 Cognitive Interaction Technology.
 * The Excellence Cluster EXC 277 is a grant of the Deutsche
 * Forschungsgemeinschaft (DFG) in the context of the German
 * Excellence Initiative.
 *
 * Contributors: Leon Ziegler, Johannes Wienke, Matthias Schröder, Norman Köster,
 * 				Lukas Twardon, Torben Töniges, Annika Rothert, Marian Pohling,
 * 				Denis Schulze, Viktor Richter, Birte Carlmeyer, Maikel Linke
 */

/** ==========================================================================
 * 
 * @file		Shirt.h --
 * @brief		Source file for btl type Shirt
 *
 * @author	Denis Schulze <dschulze@techfak.uni-bielefeld.de>
 * 
 * 1.0 / 04.06.10 (ds)
 * -from scratch
 * ========================================================================== 
 **/

#include "Shirt.h"
#include "../../units/UnitConverter.h"

namespace airobots {
LengthUnit Shirt::iLU = MILLIMETER;
AngleUnit Shirt::iAU = RADIAN;

Shirt::Shirt() {

}

Shirt::~Shirt() {

}

std::string Shirt::getBaseTag() {
	return "SHIRT";
}

std::string Shirt::getTemplate() {

	return "<" + getBaseTag() + ">" + "<GENERATOR/>"
			+ airobots::Timestamp::getTemplate()
			+ "<POSITION angle=\"\" angleVariance=\"\" distance=\"\" distanceVariance=\"\"/>"
			+ "</" + getBaseTag() + ">";

}

std::string Shirt::getPerceptName() {
	return "shirt";
}

float Shirt::getAngle(AngleUnit u) const {
	return UnitConverter::convert(angle, iAU, u);
}

void Shirt::setAngle(float angle, AngleUnit u) {
	this->angle = UnitConverter::convert(angle, u, iAU);
}

float Shirt::getAngleVariance(AngleUnit u) const {
	return UnitConverter::convert(angleVariance, iAU, u);
}

void Shirt::setAngleVariance(float variance, AngleUnit u) {
	this->angleVariance = UnitConverter::convert(variance, u, iAU);
}

float Shirt::getDistance(LengthUnit u) const {
	return UnitConverter::convert(distance, iLU, u);
}

void Shirt::setDistance(float distance, LengthUnit u) {
	this->distance = UnitConverter::convert(distance, u, iLU);
}

float Shirt::getDistanceVariance(LengthUnit u) const {
	return UnitConverter::convert(distanceVariance, iLU, u);
}

void Shirt::setDistanceVariance(float variance, LengthUnit u) {
	this->distanceVariance = UnitConverter::convert(variance, u, iLU);
}

void Shirt::sanitizeLocation(xmltio::Location &loc) const {

}

void Shirt::fillInto(xmltio::Location &loc) const {

	airobots::Type::fillInto(loc);

	loc[xmltio::XPath("POSITION/@angle")] = getAngle(iAU);
	loc[xmltio::XPath("POSITION/@angleVariance")] = getAngleVariance(iAU);
	loc[xmltio::XPath("POSITION/@distance")] = getDistance(iLU);
	loc[xmltio::XPath("POSITION/@distanceVariance")] = getDistanceVariance(iLU);

}

void Shirt::fromLocation(const xmltio::Location &loc_, Shirt &shirt) {

	airobots::Type::fromLocation(loc_, shirt);

	shirt.setAngle(
			xmltio::extract<float>(loc_[xmltio::XPath("POSITION/@angle")]),
			iAU);
	shirt.setAngleVariance(
			xmltio::extract<float>(
					loc_[xmltio::XPath("POSITION/@angleVariance")]), iAU);
	shirt.setDistance(
			xmltio::extract<float>(loc_[xmltio::XPath("POSITION/@distance")]),
			iLU);
	shirt.setDistanceVariance(
			xmltio::extract<float>(
					loc_[xmltio::XPath("POSITION/@distanceVariance")]), iLU);

}

}
