/*
 * This file is part of Bielefeld Type Library (BTL).
 *
 * Copyright(c) Frederic Siepmann
 * http://opensource.cit-ec.de/projects/btl
 *
 * This file may be licensed under the terms of of the
 * GNU Lesser General Public License Version 3 (the ``LGPL''),
 * or (at your option) any later version.
 *
 * Software distributed under the License is distributed
 * on an ``AS IS'' basis, WITHOUT WARRANTY OF ANY KIND, either
 * express or implied. See the LGPL for the specific language
 * governing rights and limitations.
 *
 * You should have received a copy of the LGPL along with this
 * program. If not, go to http://www.gnu.org/licenses/lgpl.html
 * or write to the Free Software Foundation, Inc.,
 * 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
 *
 * The development of this software was supported by the
 * Excellence Cluster EXC 277 Cognitive Interaction Technology.
 * The Excellence Cluster EXC 277 is a grant of the Deutsche
 * Forschungsgemeinschaft (DFG) in the context of the German
 * Excellence Initiative.
 *
 * Contributors: Leon Ziegler, Johannes Wienke, Matthias Schröder, Norman Köster,
 * 				Lukas Twardon, Torben Töniges, Annika Rothert, Marian Pohling,
 * 				Denis Schulze, Viktor Richter, Birte Carlmeyer, Maikel Linke
 */

#include "PlaneData.h"
#include <math.h>

using namespace xmltio;
using namespace airobots;
using namespace std;

std::string PlaneData::getBaseTag() {
	return "PLANE";
}

std::string PlaneData::getTemplate() {

	string originTemplate = Point3D::getTemplate();
	string bt = Point3D::getBaseTag();
	size_t it = originTemplate.find(bt);
	while (it != originTemplate.npos) {
		originTemplate.replace(it, bt.length(), "ORIGIN");
		it = originTemplate.find(bt);
	}

	string rotationTemplate = Rotation3D::getTemplate();
	bt = Rotation3D::getBaseTag();
	it = rotationTemplate.find(bt);
	while (it != rotationTemplate.npos) {
		rotationTemplate.replace(it, bt.length(), "ROTATION");
		it = rotationTemplate.find(bt);
	}

	return "<" + getBaseTag() + "><GENERATOR/>" + Timestamp::getTemplate()
			+ "<SCOPE />" + originTemplate + rotationTemplate
			+ PrecisePolygon::getTemplate() + "</" + getBaseTag() + ">";
}

PlaneData::PlaneData() :
		RegionData() {
}

airobots::PlaneData::PlaneData(const PlaneData & data) :
		RegionData(data), origin(data.origin), rotation(data.rotation) {
}

PlaneData::PlaneData(std::string generator) :
		RegionData(generator) {
}

void PlaneData::sanitizeLocation(xmltio::Location &loc) const {
	RegionData::sanitizeLocation(loc);
}

void PlaneData::fillInto(xmltio::Location &loc) const {

	RegionData::fillInto(loc);

	xmltio::Location originloc = loc[XPath("ORIGIN")];
	origin.fillInto(originloc);

	xmltio::Location rotationloc = loc[XPath("ROTATION")];
	rotation.fillInto(rotationloc);
}

void PlaneData::fromLocation(const xmltio::Location &loc_, PlaneData &object) {

	RegionData::fromLocation(loc_, object);

	Point3D origin = extract<Point3D>(loc_[XPath("ORIGIN")]);
	object.setOrigin(origin);

	Rotation3D rotation = extract<Rotation3D>(loc_[XPath("ROTATION")]);
	object.setRotation(rotation);
}

bool PlaneData::operator==(const PlaneData &other) const {

	bool region = RegionData::operator==(other);

	if (!(origin == other.origin)) {
		return false;
	}

	if (!(rotation == other.rotation)) {
		return false;
	}

	return region;
}

void PlaneData::setOrigin(const Point3D origin) {
	this->origin = origin;
}

Point3D PlaneData::getOrigin() const {
	return origin;
}

void PlaneData::setRotation(const Rotation3D rotation) {
	this->rotation = rotation;
}

Rotation3D PlaneData::getRotation() const {
	return rotation;
}

