/*
* This file is part of Bielefeld Type Library (BTL).
*
* Copyright(c) Frederic Siepmann
* http://opensource.cit-ec.de/projects/btl
*
* This file may be licensed under the terms of of the
* GNU Lesser General Public License Version 3 (the ``LGPL''),
* or (at your option) any later version.
*
* Software distributed under the License is distributed
* on an ``AS IS'' basis, WITHOUT WARRANTY OF ANY KIND, either
* express or implied. See the LGPL for the specific language
* governing rights and limitations.
*
* You should have received a copy of the LGPL along with this
* program. If not, go to http://www.gnu.org/licenses/lgpl.html
* or write to the Free Software Foundation, Inc.,
* 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
*
* The development of this software was supported by the
* Excellence Cluster EXC 277 Cognitive Interaction Technology.
* The Excellence Cluster EXC 277 is a grant of the Deutsche
* Forschungsgemeinschaft (DFG) in the context of the German
* Excellence Initiative.
*
* Contributors: Leon Ziegler, Johannes Wienke, Matthias Schröder, Norman Köster,
* 				Lukas Twardon, Torben Töniges, Annika Rothert, Marian Pohling,
* 				Denis Schulze, Viktor Richter, Birte Carlmeyer, Maikel Linke
*/

#include "SRCalibratedData.h"
#include "../geometry/Point3D.h"

using namespace xmltio;
using namespace airobots;
using namespace std;

std::string SRCalibratedData::getBaseTag() {
	return "SRCALIBRATEDDATA";
}

std::string SRCalibratedData::getTemplate() {
	return "<" + getBaseTag() + " scope=\"\"><GENERATOR/>" + Timestamp::getTemplate()+ "</" + getBaseTag() + ">";
}

SRCalibratedData::SRCalibratedData() :
	Type(), scope(GLOBAL) {
}

SRCalibratedData::SRCalibratedData(std::string generator) :
	Type(generator), scope(GLOBAL) {
}

SRCalibratedData::SRCalibratedData(std::string generator,
		SRCalibratedData::Scope scope) :
	Type(generator), scope(scope) {
}

void SRCalibratedData::setScope(SRCalibratedData::Scope scope) {
	this->scope = scope;
}
SRCalibratedData::Scope SRCalibratedData::getScope() const {
	return scope;
}

void SRCalibratedData::sanitizeLocation(xmltio::Location &loc) const {
	XPath xp(Point3D::getBaseTag());
	while (XPathIterator i = xp.evaluate(loc)) {
		Location l(*i);
		loc.remove(l);
	}
}

void SRCalibratedData::fillInto(xmltio::Location &loc) const {

	Type::fillInto(loc);

	if (scope == LOCAL) {
		loc[XPath("@scope")] = "LOCAL";
	} else {
		loc[XPath("@scope")] = "GLOBAL";
	}
	for (vector<Point3D>::const_iterator it = this->begin(); it != this->end(); it++) {

		Location obj(Point3D::getTemplate(), XPath(Point3D::getBaseTag()));

		it->fillInto(obj);
		loc.add(obj);
	}
}

void SRCalibratedData::fromLocation(const xmltio::Location &loc_,
		SRCalibratedData &object) {

	string scopeStr = extract<string> (loc_[XPath("@scope")]);
	if (scopeStr == "LOCAL") {
		object.setScope(LOCAL);
	} else {
		object.setScope(GLOBAL);
	}
	for (XPathIterator iter = XPath(Point3D::getBaseTag()).evaluate(loc_); iter; ++iter) {
		Location l(*iter);
		Point3D data = extract<Point3D> (l);
		object.push_back(data);
	}
}
