/*
 * This file is part of Bielefeld Type Library (BTL).
 * 
 * Copyright(c) Frederic Siepmann http://opensource.cit-ec.de/projects/btl
 * 
 * This file may be licensed under the terms of of the GNU Lesser General Public
 * License Version 3 (the ``LGPL''), or (at your option) any later version.
 * 
 * Software distributed under the License is distributed on an ``AS IS'' basis,
 * WITHOUT WARRANTY OF ANY KIND, either express or implied. See the LGPL for the
 * specific language governing rights and limitations.
 * 
 * You should have received a copy of the LGPL along with this program. If not,
 * go to http://www.gnu.org/licenses/lgpl.html or write to the Free Software
 * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301,
 * USA.
 * 
 * The development of this software was supported by the Excellence Cluster EXC
 * 277 Cognitive Interaction Technology. The Excellence Cluster EXC 277 is a
 * grant of the Deutsche Forschungsgemeinschaft (DFG) in the context of the
 * German Excellence Initiative.
 * 
 * Contributors: Leon Ziegler, Johannes Wienke, Matthias Schröder, Norman
 * Köster, Lukas Twardon, Torben Töniges, Annika Rothert, Marian Pohling, Denis
 * Schulze, Viktor Richter, Birte Carlmeyer, Maikel Linke
 */
package de.unibi.airobots.btl.data.person;

import java.util.ArrayList;

import de.unibi.airobots.btl.Type;

import nu.xom.Element;
import nu.xom.Node;
import nu.xom.Nodes;

/**
 * A collection of person data.
 * 
 * @author: Denis Schulze <dschulze@techfak.uni-bielefeld.de>
 */
public class PersonDataList extends Type {

	private ArrayList<PersonData> personData;

	/** Constructor. */
	public PersonDataList() {
		super();
		personData = new ArrayList<PersonData>();
	}

	/** Adds new person data to this list. */
	public void addPersonData(PersonData data) {
		personData.add(data);
	}

	/** Returns the person data from the list. */
	public PersonData getPersonData(int index) {
		if (index > personData.size())
			return null;

		return personData.get(index);
	}

	/** Removes all person data from this list. */
	public void clearList() {
		personData.clear();
	}

	/** Returns the number of stored person data. */
	public int size() {
		return personData.size();
	}

	/** Returns the base tag as a string. */
	public static String getBaseTag() {
		return "PERSONS";
	}

	/** {@inheritDoc} */
	public static void fromElement(Element element, PersonDataList type) {

		Type.fromElement(element, type);

		Nodes nodes = element.query(PersonData.getBaseTag());
		int nrNodes = nodes.size();
		for (int i = 0; i < nrNodes; i++) {

			Node node = nodes.get(i);
			if (node instanceof Element) {

				Element personElement = (Element) node;

				PersonData parsed = new PersonData();
				PersonData.fromElement(personElement, parsed);
				type.addPersonData(parsed);

			}

		}

	}

	/** {@inheritDoc} */
	@Override
	public void fillInto(Element parent) {
		super.fillInto(parent);

		int nrPersonData = personData.size();
		for (int i = 0; i < nrPersonData; i++) {

			Element personDataElement = new Element(PersonData.getBaseTag());
			personData.get(i).fillInto(personDataElement);
			parent.appendChild(personDataElement);

		}

	}

}
