package de.unibi.airobots.btl.data.taskpattern;

import nu.xom.Element;
import nu.xom.Node;
import nu.xom.Nodes;
import de.unibi.airobots.btl.data.common.ElementParser;
import de.unibi.airobots.btl.data.common.UnexpectedElementFormatException;

/**
 * Send by the dialog to the system. system should handle this.
 * @author arothert, vrichter, bcarlmey
 */
public class Say extends TaskPatternBase {

	static final String UTTERANCE_ELEM = "UTTERANCE";
	static final String LENGTH_ELEM = "length";


	private String utterance;
	private int length;
	
	public Say() {	
	}
	
	/**
	 * the base tag should be named after the class itself.
	 * @return
	 */
	public static String getBaseTag() {
		return "SAY";
	}
	
	/**
	 * {@inheritDoc}
	 */
	@Override
	public void fillInto(Element parent) {
		super.fillInto(parent);
		Element utteranceElement = new Element(UTTERANCE_ELEM, utterance);
		Element statesElement = 
			TaskPatternStatusTagData.createTaskStatusElement(getOrigin(), getValue());
		Element lengthElement = new Element(LENGTH_ELEM, ("" + length));
		parent.appendChild(utteranceElement);
		parent.appendChild(statesElement);
		parent.appendChild(lengthElement);
	}
		
	public static void fromElement(Element element, Say type) {
		Nodes nodes = element.query("*");
		for (int i = 0; i < nodes.size(); i++) {
			Node node = nodes.get(i);
			if (node instanceof Element) {
				Element elem = (Element) node;
				if (elem.getLocalName().equals(UTTERANCE_ELEM)) {
					try {
						type.setUtterance(ElementParser.getTagValue(elem));
					} catch (UnexpectedElementFormatException e) {
						type.setUtterance("");
					}
				}
				if (elem.getLocalName().equals(STATUS_TAG)) {
					type.setValue(ElementParser.getAttributeValue(elem, VALUE_ATT));
					type.setOrigin(ElementParser.getAttributeValue(elem, ORIGIN_ATT));	
				}
				if (elem.getLocalName().equals(LENGTH_ELEM)) {
					try {
						type.setLength(ElementParser.getTagValue(elem));
					} catch (UnexpectedElementFormatException e) {
						type.setLength(0);
					}
				}
			}
		}
	}

	/**
	 * {@inheritDoc}
	 */
	@Override
	public String toString() {
		StringBuilder strb = new StringBuilder();
		strb.append("["+getBaseTag()+": ");
		strb.append("[UTTERANCE: " + utterance + "]");
		strb.append("[STATUS: ");
		strb.append("value: " + value + "; ");
		strb.append("origin: " + origin + "]");
		strb.append("[length: " + length + "]]");
		return strb.toString();
	}
	
	public String getUtterance() {
		return utterance;
	}

	public void setUtterance(String utterance) {
		this.utterance = utterance;
	}

	public int getLength() {
		return length;
	}

	public void setLength(int length) {
		this.length = length;
	}
	
	public void setLength(String length) {
		this.length = Integer.parseInt(length);
	}
}
